@@ -38,7 +38,7 @@ from idds.client.version import release_version
 from idds.client.client import Client
 from idds.common import exceptions
 from idds.common.config import get_local_cfg_file, get_local_config_root, get_local_config_value
-from idds.common.constants import RequestType, RequestStatus
+from idds.common.constants import RequestType, RequestStatus, ProcessingStatus
 # from idds.common.utils import get_rest_host, exception_handler
 from idds.common.utils import exception_handler
 
@@ -87,6 +87,8 @@ class ClientManager:
                 client_host = self.auth_type_host
             else:
                 client_host = self.host
+            if self.auth_type is None:
+                self.auth_type = 'x509_proxy'
             self.client = Client(host=client_host,
                                  auth={'auth_type': self.auth_type,
                                        'client_proxy': self.x509_proxy,
@@ -104,7 +106,7 @@ class ClientManager:
         return local_cfg
 
     def get_config_value(self, configuration, section, name, current, default):
-        if type(configuration) in [str]:
+        if configuration and type(configuration) in [str]:
             config = ConfigParser.SafeConfigParser()
             config.read(configuration)
             configuration = config
@@ -114,11 +116,18 @@ class ClientManager:
     def get_local_configuration(self):
         local_cfg = self.get_local_cfg_file()
         config = ConfigParser.SafeConfigParser()
-        if os.path.exists(local_cfg):
+        if not local_cfg:
+            logging.debug("local configuration file does not exist, will only load idds default value.")
+        if local_cfg and os.path.exists(local_cfg):
             config.read(local_cfg)
 
-        self.config = self.get_config_value(config, section='common', name='config', current=self.config,
-                                            default=os.path.join(self.get_local_config_root(), 'idds.cfg'))
+        if self.get_local_config_root():
+            self.config = self.get_config_value(config, section='common', name='config', current=self.config,
+                                                default=os.path.join(self.get_local_config_root(), 'idds.cfg'))
+        else:
+            self.config = self.get_config_value(config, section='common', name='config', current=self.config,
+                                                default=None)
+
         self.auth_type = self.get_config_value(config, 'common', 'auth_type', current=self.auth_type, default='x509_proxy')
 
         self.host = self.get_config_value(config, 'rest', 'host', current=self.host, default=None)
@@ -131,16 +140,24 @@ class ClientManager:
             if proxy:
                 self.x509_proxy = proxy
 
-        self.oidc_token = self.get_config_value(config, 'oidc', 'oidc_token', current=self.oidc_token,
-                                                default=os.path.join(self.get_local_config_root(), '.oidc_token'))
+        if self.get_local_config_root():
+            self.oidc_token = self.get_config_value(config, 'oidc', 'oidc_token', current=self.oidc_token,
+                                                    default=os.path.join(self.get_local_config_root(), '.oidc_token'))
+        else:
+            self.oidc_token = self.get_config_value(config, 'oidc', 'oidc_token', current=self.oidc_token,
+                                                    default=None)
+
         self.vo = self.get_config_value(config, self.auth_type, 'vo', current=self.vo, default=None)
 
         self.configuration = config
 
     def save_local_configuration(self):
         local_cfg = self.get_local_cfg_file()
-        with open(local_cfg, 'w') as configfile:
-            self.configuration.write(configfile)
+        if not local_cfg:
+            logging.debug("local configuration file does not exist, will not store current setup.")
+        else:
+            with open(local_cfg, 'w') as configfile:
+                self.configuration.write(configfile)
 
     def setup_local_configuration(self, local_config_root=None, config=None, host=None,
                                   auth_type=None, auth_type_host=None, x509_proxy=None,
@@ -361,6 +378,39 @@ class ClientManager:
         else:
             return (-1, 'No matching requests')
 
+    @exception_handler
+    def abort_tasks(self, request_id=None, workload_id=None, task_id=None):
+        """
+        Abort tasks.
+
+        :param workload_id: the workload id.
+        :param request_id: the request.
+        :param task_id: The task id.
+        """
+        self.setup_client()
+
+        if request_id is None and workload_id is None:
+            logging.error("Both request_id and workload_id are None. One of them should not be None")
+            return (-1, "Both request_id and workload_id are None. One of them should not be None")
+        if task_id is None:
+            logging.error("The task_id is required for killing tasks. If you want to kill the whole workflow, please try another API.")
+            return (-1, "The task_id is required for killing tasks")
+
+        reqs = self.client.get_requests(request_id=request_id, workload_id=workload_id, with_processing=True)
+        if reqs:
+            rets = []
+            for req in reqs:
+                if str(req['processing_workload_id']) == str(task_id):
+                    logging.info("Aborting task: (request_id: %s, task_id: %s)" % (req['request_id'], task_id))
+                    self.client.send_message(request_id=req['request_id'], msg={'command': 'update_processing',
+                                                                                'parameters': [{'status': ProcessingStatus.ToCancel, 'workload_id': task_id}]})
+                    logging.info("Abort task registered successfully: (request_id %s, task_id: %s)" % (req['request_id'], task_id))
+                    ret = (0, "Abort task registered successfully: (request_id %s, task_id: %s)" % (req['request_id'], task_id))
+                    rets.append(ret)
+            return rets
+        else:
+            return (-1, 'No matching requests')
+
     @exception_handler
     def suspend(self, request_id=None, workload_id=None):
         """
